==> mozilla-source-1.1b.tar.gz: mozilla/gfx/src/mac/nsATSUIUtils.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsATSUIUtils_h___
#define nsATSUIUtils_h___


#include "nsCRT.h"
#include "nsError.h"
#include "nsCoord.h"
#include "nsColor.h"
#include "nsIRenderingContext.h"
#include <ATSUnicode.h>

class ATSUILayoutCache;
class nsDrawingSurfaceMac;
class nsIDeviceContext;

class nsATSUIUtils
{
public:
  static void Initialize();
  static PRBool IsAvailable();

  static ATSUILayoutCache*  gTxLayoutCache;

private:
  static PRBool gIsAvailable;
  static PRBool gInitialized;
};



class nsATSUIToolkit
{
public:
  nsATSUIToolkit();
  ~nsATSUIToolkit() {};

  void PrepareToDraw(CGrafPtr aPort, nsIDeviceContext* aContext);
 
  nsresult GetTextDimensions(const PRUnichar *aCharPt, nsTextDimensions &oDim, 
                             short aSize, short fontNum, PRBool aBold, 
                             PRBool aItalic, nscolor aColor);
  nsresult DrawString(const PRUnichar *aCharPt, PRInt32 x, PRInt32 y, short &oWidth, 
                      short aSize, short fontNum, PRBool aBold, PRBool aItalic, 
                      nscolor aColor);
#ifdef MOZ_MATHML
  nsresult GetBoundingMetrics(const PRUnichar *aCharPt, nsBoundingMetrics &aBoundingMetrics,
                              short aSize, short fontNum, PRBool aBold, 
                              PRBool aItalic, nscolor aColor);
#endif // MOZ_MATHML

private:
  void StartDraw(const PRUnichar *aCharPt, short aSize, short fontNum, PRBool aBold,
                 PRBool aItalic, nscolor aColor, ATSUTextLayout& oLayout);

  ATSUTextLayout GetTextLayout(short aFontNum, short aSize, PRBool aBold, 
                               PRBool aItalic, nscolor aColor);
  
private:
  CGrafPtr        mPort;
  nsIDeviceContext*  mContext;
};

#endif //nsATSUIUtils_h___

==> mozilla-source-1.8a6.tar.gz: mozilla/gfx/src/mac/nsATSUIUtils.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsATSUIUtils_h___
#define nsATSUIUtils_h___


#include "nsCRT.h"
#include "nsError.h"
#include "nsCoord.h"
#include "nsColor.h"
#include "nsIRenderingContext.h"
#include <ATSUnicode.h>

class ATSUILayoutCache;
class nsDrawingSurfaceMac;
class nsIDeviceContext;

class nsATSUIUtils
{
public:
  static void Initialize();
  static PRBool IsAvailable();

  static ATSUILayoutCache*  gTxLayoutCache;

private:
  static PRBool gIsAvailable;
  static PRBool gInitialized;
};



class nsATSUIToolkit
{
public:
  nsATSUIToolkit();
  ~nsATSUIToolkit() {};

  void PrepareToDraw(CGrafPtr aPort, nsIDeviceContext* aContext);
 
  nsresult GetTextDimensions(const PRUnichar *aCharPt, PRUint32 aLen, nsTextDimensions &oDim, 
                             short aSize, short fontNum, PRBool aBold, 
                             PRBool aItalic, nscolor aColor);
  nsresult DrawString(const PRUnichar *aCharPt, PRUint32 aLen, PRInt32 x, PRInt32 y, short &oWidth, 
                      short aSize, short fontNum, PRBool aBold, PRBool aItalic, 
                      nscolor aColor);
#ifdef MOZ_MATHML
  nsresult GetBoundingMetrics(const PRUnichar *aCharPt, PRUint32 aLen, nsBoundingMetrics &aBoundingMetrics,
                              short aSize, short fontNum, PRBool aBold, 
                              PRBool aItalic, nscolor aColor);
#endif // MOZ_MATHML

private:
  void StartDraw(const PRUnichar *aCharPt, PRUint32 aLen, short aSize, short fontNum, PRBool aBold,
                 PRBool aItalic, nscolor aColor, ATSUTextLayout& oLayout);

  ATSUTextLayout GetTextLayout(short aFontNum, short aSize, PRBool aBold, 
                               PRBool aItalic, nscolor aColor);
  
private:
  CGrafPtr        mPort;
  nsIDeviceContext*  mContext;
};

#endif //nsATSUIUtils_h___
